@@ -1,8 +1,8 @@
 package storage_test
 
 import (
-	"github.com/tomwright/dasel"
-	"github.com/tomwright/dasel/storage"
+	"github.com/tomwright/dasel/v2"
+	"github.com/tomwright/dasel/v2/storage"
 	"reflect"
 	"testing"
 )
